@@ -140,6 +140,7 @@ class ColorDetectionUseCase(BaseProcessor):
 
         self._ascending_alert_list: List[int] = []
         self.current_incident_end_timestamp: str = "N/A"
+        self.color_det_dict = {}
 
     def reset_tracker(self) -> None:
         """Reset the advanced tracker instance."""
@@ -262,10 +263,12 @@ class ColorDetectionUseCase(BaseProcessor):
             color = det.get('main_color')
             track_id = det.get('track_id')
             if cat and track_id is not None:
-                # If color not yet computed at this stage, fall back to category-only key
-                key = f"{cat}:{color}" if color else cat
-                self._color_total_track_ids[key].add(track_id)
-                self._color_current_frame_track_ids[key].add(track_id)
+                if track_id not in self.color_det_dict.items():
+                    self.color_det_dict[track_id]=color  
+                    # If color not yet computed at this stage, fall back to category-only key
+                    key = f"{cat}:{color}" if color else cat
+                    self._color_total_track_ids[key].add(track_id)
+                    self._color_current_frame_track_ids[key].add(track_id)
 
     def get_total_color_counts(self):
         """Return total unique track_id count per color (across all categories)."""
@@ -1023,6 +1026,9 @@ class ColorDetectionUseCase(BaseProcessor):
         high_precision_reset_timestamp = self._get_start_timestamp_str(stream_info, precision=True)
 
         camera_info = self.get_camera_info_from_stream(stream_info)
+        print("----------------COLOR_DICT----------------")
+        print(self.color_det_dict)
+        print("----------------COLOR_DICT----------------")
         human_text_lines = []
 
         # CURRENT FRAME section
@@ -1051,6 +1057,7 @@ class ColorDetectionUseCase(BaseProcessor):
         human_text_lines.append(f"TOTAL SINCE {start_timestamp}:")
         human_text_lines.append(f"\t- Total Detected (by color): {cumulative_total}")
         # Add category-wise totals
+        
         if total_category_counts_dict:
             human_text_lines.append("\t- Categories:")
             for cat, count in total_category_counts_dict.items():
