@@ -38,10 +38,10 @@ class LicensePlateMonitorConfig(BaseConfig):
     frame_skip: int = 1
     fps: Optional[float] = None
     bbox_format: str = "auto"
-    usecase_categories: List[str] = field(default_factory=lambda: ['license_plate'])
-    target_categories: List[str] = field(default_factory=lambda: ['license_plate'])
+    usecase_categories: List[str] = field(default_factory=lambda: ['License_Plate'])
+    target_categories: List[str] = field(default_factory=lambda: ['License_Plate'])
     alert_config: Optional[AlertConfig] = None
-    index_to_category: Optional[Dict[int, str]] = field(default_factory=lambda: {0: "license_plate"})
+    index_to_category: Optional[Dict[int, str]] = field(default_factory=lambda: {0: "License_Plate"})
     language: List[str] = field(default_factory=lambda: ['en', 'ar'])
     country: str = field(default_factory=lambda: 'qatar')
 
@@ -63,12 +63,12 @@ class LicensePlateMonitorConfig(BaseConfig):
         return errors
 
 class LicensePlateMonitorUseCase(BaseProcessor):
-    CATEGORY_DISPLAY = {"license_plate": "License Plate"}
+    CATEGORY_DISPLAY = {"License_Plate": "License Plate"}
     
     def __init__(self):
         super().__init__("license_plate_monitor")
         self.category = "license_plate_monitor"
-        self.target_categories = ['license_plate']
+        self.target_categories = ['License_Plate']
         self.CASE_TYPE: Optional[str] = 'license_plate_monitor'
         self.CASE_VERSION: Optional[str] = '1.3'
         self.smoothing_tracker = None
@@ -323,7 +323,7 @@ class LicensePlateMonitorUseCase(BaseProcessor):
                     ocr_record = {
                         "frame_id": frame_key,
                         "timestamp": round(timestamp, 2),
-                        "category": detection.get("category", "license_plate"),
+                        "category": detection.get("category", "License_Plate"),
                         "confidence": round(detection.get("confidence", 0.0), 3),
                         "plate_text": plate_text,
                         "bbox": bbox,
@@ -376,7 +376,7 @@ class LicensePlateMonitorUseCase(BaseProcessor):
             ocr_record = {
                 "frame_id": "0",
                 "timestamp": 0.0,
-                "category": detection.get("category", "license_plate"),
+                "category": detection.get("category", "License_Plate"),
                 "confidence": round(detection.get("confidence", 0.0), 3),
                 "plate_text": plate_text,
                 "bbox": bbox,
@@ -424,14 +424,31 @@ class LicensePlateMonitorUseCase(BaseProcessor):
             return []
 
     def _update_detections_with_ocr(self, detections: List[Dict[str, Any]], ocr_analysis: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
-        """Update detections with OCR results based on detection_id or track_id."""
-        ocr_dict = {rec["detection_id"]: rec["plate_text"] for rec in ocr_analysis}
+        """Update detections with OCR results using track_id or bounding box for matching."""
+        ocr_dict = {}
+        for rec in ocr_analysis:
+            if rec.get("plate_text"):
+                # Primary key: track_id
+                track_id = rec.get("track_id")
+                if track_id is not None:
+                    ocr_dict[track_id] = rec["plate_text"]
+                # Fallback key: bounding box as tuple
+                else:
+                    bbox_key = tuple(sorted(rec["bbox"].items())) if rec.get("bbox") else None
+                    if bbox_key:
+                        ocr_dict[bbox_key] = rec["plate_text"]
+                self.logger.debug(f"OCR record: track_id={track_id}, plate_text={rec.get('plate_text')}, bbox={rec.get('bbox')}")
+        
         for det in detections:
-            det_id = det.get("detection_id", det.get("id", det.get("track_id")))
-            if det_id in ocr_dict:
-                det["plate_text"] = ocr_dict[det_id]
-            else:
-                det["plate_text"] = None
+            track_id = det.get("track_id")
+            bbox_key = tuple(sorted(det.get("bounding_box", det.get("bbox", {})).items())) if det.get("bounding_box") or det.get("bbox") else None
+            plate_text = None
+            if track_id is not None and track_id in ocr_dict:
+                plate_text = ocr_dict[track_id]
+            elif bbox_key and bbox_key in ocr_dict:
+                plate_text = ocr_dict[bbox_key]
+            det["plate_text"] = plate_text
+            self.logger.debug(f"Detection track_id={track_id}, bbox={det.get('bounding_box')}: Assigned plate_text={plate_text}")
         return detections
 
     def _count_categories(self, detections: List[Dict], config: LicensePlateMonitorConfig) -> Dict[str, Any]:
@@ -442,7 +459,7 @@ class LicensePlateMonitorUseCase(BaseProcessor):
             if not all(k in det for k in ['category', 'confidence', 'bounding_box']):
                 self.logger.warning(f"Skipping invalid detection: {det}")
                 continue
-            cat = det.get('category', 'license_plate')
+            cat = det.get('category', 'License_Plate')
             counts[cat] = counts.get(cat, 0) + 1
             valid_detections.append({
                 "bounding_box": det.get("bounding_box"),
@@ -484,6 +501,8 @@ class LicensePlateMonitorUseCase(BaseProcessor):
             plate_texts = [det.get("plate_text") for det in counting_summary.get("detections", []) if det.get("plate_text")]
             if plate_texts:
                 human_text_lines.append(f"\t- License Plates: {', '.join(plate_texts)}")
+            else:
+                human_text_lines.append(f"\t- License Plates: None")
         else:
             human_text_lines.append(f"\t- No detections")
         
@@ -506,7 +525,7 @@ class LicensePlateMonitorUseCase(BaseProcessor):
         detections = []
         for detection in counting_summary.get("detections", []):
             bbox = detection.get("bounding_box", {})
-            category = detection.get("category", "license_plate")
+            category = detection.get("category", "License_Plate")
             plate_text = detection.get("plate_text", "")
             segmentation = detection.get("masks", detection.get("segmentation", detection.get("mask", [])))
             detection_obj = self.create_detection_object(category, bbox, segmentation=segmentation, plate_text=plate_text)
@@ -721,7 +740,7 @@ class LicensePlateMonitorUseCase(BaseProcessor):
 
     def get_total_counts(self):
         """Return total unique track_id count for each category."""
-        return {'license_plate': len(self._seen_plate_texts)}
+        return {'License_Plate': len(self._seen_plate_texts)}
 
     def _get_track_ids_info(self, detections: List[Dict]) -> Dict[str, Any]:
         """Get detailed information about track IDs."""
